netapp_ontap.models.acl API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.acl`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AclSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Acl object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access: str GET POST PATCH`

    Specifies whether the ACL is for DACL or SACL. The available values are:

    - access_allow - DACL for allow access
    - access_deny - DACL for deny access
    - access_allowed_callback - CALLBACK for allowed access
    - access_denied_callback - CALLBACK for denied access
    - access_allowed_callback_object - CALLBACK OBJECT for allowed access
    - access_denied_callback_object - CALLBACK OBJECT for denied access
    - system_audit_callback - SYSTEM Audit Callback ace
    - system_audit_callback_object - SYSTEM Audit Callback Object ace
    - system_resource_attribute - SYSTEM Resource Attribute
    - system_scoped_policy_id - SYSTEM Scope Policy ID
    - audit_success - SACL for success access
    - audit_failure - SACL for failure access
    - audit_success_and_failure - SACL for both success and failure access

    Valid choices:

    - access_allow
    - access_deny
    - access_allowed_callback
    - access_denied_callback
    - access_allowed_callback_object
    - access_denied_callback_object
    - system_audit_callback
    - system_audit_callback_object
    - system_resource_attribute
    - system_scoped_policy_id
    - audit_failure
    - audit_success
    - audit_success_and_failure
  `access_control: str GET`

    An Access Control Level specifies the access control of the task to be applied. Valid values are "file-directory" or "Storage-Level Access Guard (SLAG)". SLAG is used to apply the specified security descriptors with the task for the volume or qtree. Otherwise, the security descriptors are applied on files and directories at the specified path. The value SLAG is not supported on FlexGroups volumes. The default value is "file-directory" ('-' and '_' are interchangeable).

    Valid choices:

    - file_directory
    - slag
  `advanced_rights: AdvancedRights GET POST PATCH`

    Specifies the advanced access right controlled by the ACE for the account specified. You can specify more than one "advanced-rights" value by using a comma-delimited list.

  `apply_to: ApplyTo GET POST PATCH`

    Specifies where to apply the DACL or SACL entries. You can specify more than one value by using a comma-delimited list.

  `inherited: bool GET`

    Indicates whether or not the ACE flag is inherited.

    Example: true

  `rights: str GET POST PATCH`

    The rights field of the acl.

  `user: str GET POST`

    Specifies the account to which the ACE applies. You can specify either name or SID.

    Example: S-1-5-21-2233347455-2266964949-1780268902-69304